#
# spec file for package shinken
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

%define	shinken_ver	0.5
Name:           shinken
Version:        0.5.1
Release:        2.20
License:        GPL v2 or later
Summary:        Distributed Monitoring Solution
Url:            http://www.shinken-monitoring.org
Group:          System/Monitoring
Source0:        http://shinken-monitoring.org/pub/%{name}-%{version}.tar.bz2
BuildRequires:  python-setuptools
BuildRequires:	python-Pyro
Requires:       python >= 2.4
Requires:	python-Pyro
Requires(pre):	pwdutils
Recommends:     %{name}-arbiter    = %{version}
Recommends:     %{name}-broker     = %{version}
Recommends:     %{name}-poller     = %{version}
Recommends:     %{name}-reactioner = %{version}
Recommends:     %{name}-scheduler  = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Shinken is a new Monitoring Tool, allowing distributed monitoring.
Each component can run standalone on a dedicated machine and is independent
from the rest of the monitoring system. As result it's not a problem if
parts of the monitoring system hang or are down. As part of HA funtionality,
it's possible to configure a hot failover in a larger setup.

%package arbiter
Summary:        The arbiter
Group:          System/Monitoring
Requires:       python >= 2.4

%description arbiter
* reads the configuration and checks them for errors.
* creates python objects and sends them to the scheduler
* checks continuously all processes
* splits up the configuration and deploys them to the dedicated schedulers
* reads the command pipe and sends commands to the right scheduler

%package scheduler
Summary:        Shinken scheduler
Group:          System/Monitoring
Requires:       python >= 2.4

%description scheduler
* decides about host and service check times
* handles dependencies between hosts and services
* handles check results
* checks freshness of checks
+ creates 'Broks' (Log, Statusupdate) for the broker(s)

%package poller
Summary:        Shinken poller
Group:          System/Monitoring
Requires:       python >= 2.4

%description poller
* Starts the worker processes (recommendation: same as CPUs)
* splits up the todos onto the different workers
* worker(s) handle the processes and checks their results
* worker(s) return the results to the poller

%package reactionner
Summary:        Shinken reactioner
Group:          System/Monitoring
Requires:       python >= 2.4

%description reactionner
Same behaviour as poller - but used for eventhandlers.

%package broker
Summary:        Shinken broker
Group:          System/Monitoring
Requires:       python >= 2.4

%description broker
The replacement for Nagios Event Brokers. Is also responsible for
Logging.

Handles modules for different types of usage:
* Logging
* status.dat
* Livestatus
* NDO (MySQL and Oracle)
* Merlin (MySQL adn SQLite)
* ...

%prep
%setup -q

%build
%install
python setup.py install --root=%{buildroot} --prefix=%{_prefix}

%clean
rm -rf %{buildroot}

%pre
getent group shinken >/dev/null || groupadd -r shinken
getent passwd shinken >/dev/null || useradd -r -g shinken -d /var/lib/shinken -s /sbin/nologin -c "User for shinken monitoring" shinken
exit 0


%files
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/default/shinken
%{_sysconfdir}/init.d/shinken
%{_sysconfdir}/init.d/shinken-arbiter
%{_sysconfdir}/init.d/shinken-broker
%{_sysconfdir}/init.d/shinken-poller
%{_sysconfdir}/init.d/shinken-reactionner
%{_sysconfdir}/init.d/shinken-scheduler
%dir %{_sysconfdir}/shinken
%dir %{_sysconfdir}/shinken/certs
%dir %{_sysconfdir}/shinken/objects
%dir %{_sysconfdir}/shinken/objects/contacts
%dir %{_sysconfdir}/shinken/objects/hosts
%dir %{_sysconfdir}/shinken/objects/services
%config(noreplace) %{_sysconfdir}/shinken/brokerd-windows.ini
%config(noreplace) %{_sysconfdir}/shinken/brokerd.ini
%config(noreplace) %{_sysconfdir}/shinken/certs/ca.pem
%config(noreplace) %{_sysconfdir}/shinken/certs/client.pem
%config(noreplace) %{_sysconfdir}/shinken/certs/server.pem
%config(noreplace) %{_sysconfdir}/shinken/commands.cfg
%config(noreplace) %{_sysconfdir}/shinken/contactgroups.cfg
%config(noreplace) %{_sysconfdir}/shinken/dependencies.cfg
%config(noreplace) %{_sysconfdir}/shinken/escalations.cfg
%config(noreplace) %{_sysconfdir}/shinken/hostgroups.cfg
%config(noreplace) %{_sysconfdir}/shinken/nagios-windows.cfg
%config(noreplace) %{_sysconfdir}/shinken/nagios.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/contacts/linux_admin.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/contacts/windows_admin.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/hosts/applications.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/hosts/databasehost-asia.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/hosts/databasehost-us.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/hosts/databasehost1.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/hosts/databasehost2.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/hosts/databasehost3.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/hosts/localhost.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/hosts/router-asia.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/hosts/router-us.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/hosts/router1.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/hosts/srv-ipvs-1.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/hosts/srv-ipvs-2.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/hosts/srv-nfs-1.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/hosts/srv-nfs-2.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/hosts/srv-web-1.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/hosts/srv-web-2.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/hosts/srv-web-3.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/hosts/srv-web-asia.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/hosts/srv-web-us.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/services/apache-asia.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/services/apache-us.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/services/apache.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/services/dotcomsite.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/services/erp.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/services/ipvs.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/services/linux_disks.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/services/mysql.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/services/nfs.cfg
%config(noreplace) %{_sysconfdir}/shinken/objects/services/router_ports.cfg
%config(noreplace) %{_sysconfdir}/shinken/pollerd-windows.ini
%config(noreplace) %{_sysconfdir}/shinken/pollerd.ini
%config(noreplace) %{_sysconfdir}/shinken/reactionnerd.ini
%config(noreplace) %{_sysconfdir}/shinken/resource.cfg
%config(noreplace) %{_sysconfdir}/shinken/schedulerd-windows.ini
%config(noreplace) %{_sysconfdir}/shinken/schedulerd.ini
%config(noreplace) %{_sysconfdir}/shinken/servicegroups.cfg
%config(noreplace) %{_sysconfdir}/shinken/shinken-specific-high-availability.cfg
%config(noreplace) %{_sysconfdir}/shinken/shinken-specific-load-balanced-only.cfg
%config(noreplace) %{_sysconfdir}/shinken/shinken-specific.cfg
%config(noreplace) %{_sysconfdir}/shinken/templates.cfg
%config(noreplace) %{_sysconfdir}/shinken/timeperiods.cfg
%{_bindir}/shinken-arbiter
%{_bindir}/shinken-broker
%{_bindir}/shinken-poller
%{_bindir}/shinken-reactionner
%{_bindir}/shinken-scheduler
%dir %{_prefix}/lib/nagios
%dir %{_prefix}/lib/nagios/plugins
%{_prefix}/lib/nagios/plugins/check.sh
%dir %{py_sitedir}/Shinken-%{shinken_ver}-py%{py_ver}.egg-info
%{py_sitedir}/Shinken-%{shinken_ver}-py%{py_ver}.egg-info/PKG-INFO
%{py_sitedir}/Shinken-%{shinken_ver}-py%{py_ver}.egg-info/SOURCES.txt
%{py_sitedir}/Shinken-%{shinken_ver}-py%{py_ver}.egg-info/dependency_links.txt
%{py_sitedir}/Shinken-%{shinken_ver}-py%{py_ver}.egg-info/not-zip-safe
%{py_sitedir}/Shinken-%{shinken_ver}-py%{py_ver}.egg-info/requires.txt
%{py_sitedir}/Shinken-%{shinken_ver}-py%{py_ver}.egg-info/top_level.txt
%dir %{py_sitedir}/shinken
%{py_sitedir}/shinken/__init__.py*
%{py_sitedir}/shinken/acknowledge.py*
%{py_sitedir}/shinken/action.py*
%{py_sitedir}/shinken/arbiterlink.py*
%{py_sitedir}/shinken/autoslots.py*
%{py_sitedir}/shinken/borg.py*
%{py_sitedir}/shinken/brok.py*
%{py_sitedir}/shinken/brokerlink.py*
%{py_sitedir}/shinken/check.py*
%{py_sitedir}/shinken/command.py*
%{py_sitedir}/shinken/comment.py*
%{py_sitedir}/shinken/config.py*
%{py_sitedir}/shinken/contact.py*
%{py_sitedir}/shinken/contactdowntime.py*
%{py_sitedir}/shinken/contactgroup.py*
%{py_sitedir}/shinken/daemon.py*
%{py_sitedir}/shinken/daterange.py*
%{py_sitedir}/shinken/db.py*
%{py_sitedir}/shinken/db_mysql.py*
%{py_sitedir}/shinken/db_oracle.py*
%{py_sitedir}/shinken/db_sqlite.py*
%{py_sitedir}/shinken/dependencynode.py*
%{py_sitedir}/shinken/dispatcher.py*
%{py_sitedir}/shinken/downtime.py*
%{py_sitedir}/shinken/easter.py*
%{py_sitedir}/shinken/escalation.py*
%{py_sitedir}/shinken/eventhandler.py*
%{py_sitedir}/shinken/external_command.py*
%{py_sitedir}/shinken/graph.py*
%{py_sitedir}/shinken/host.py*
%{py_sitedir}/shinken/hostdependency.py*
%{py_sitedir}/shinken/hostescalation.py*
%{py_sitedir}/shinken/hostgroup.py*
%{py_sitedir}/shinken/item.py*
%{py_sitedir}/shinken/itemgroup.py*
%{py_sitedir}/shinken/load.py*
%{py_sitedir}/shinken/log.py*
%{py_sitedir}/shinken/macroresolver.py*
%{py_sitedir}/shinken/memoized.py*
%{py_sitedir}/shinken/message.py*
%{py_sitedir}/shinken/module.py*
%dir %{py_sitedir}/shinken/modules
%dir %{py_sitedir}/shinken/modules/couchdb_broker
%{py_sitedir}/shinken/modules/couchdb_broker/__init__.py*
%{py_sitedir}/shinken/modules/couchdb_broker/couchdb_broker.py*
%{py_sitedir}/shinken/modules/dummy_arbiter.py*
%{py_sitedir}/shinken/modules/dummy_scheduler.py*
%{py_sitedir}/shinken/modules/glpi_import_arbiter.py*
%dir %{py_sitedir}/shinken/modules/host_perfdata_broker
%{py_sitedir}/shinken/modules/host_perfdata_broker/__init__.py*
%{py_sitedir}/shinken/modules/host_perfdata_broker/host_perfdata_broker.py*
%dir %{py_sitedir}/shinken/modules/livestatus_broker
%{py_sitedir}/shinken/modules/livestatus_broker/__init__.py*
%{py_sitedir}/shinken/modules/livestatus_broker/livestatus.py*
%{py_sitedir}/shinken/modules/livestatus_broker/livestatus_broker.py*
%{py_sitedir}/shinken/modules/memcache_retention_scheduler.py*
%dir %{py_sitedir}/shinken/modules/merlindb_broker
%{py_sitedir}/shinken/modules/merlindb_broker/__init__.py*
%{py_sitedir}/shinken/modules/merlindb_broker/merlindb_broker.py*
%{py_sitedir}/shinken/modules/nagios_retention_file_scheduler.py*
%dir %{py_sitedir}/shinken/modules/ndodb_mysql_broker
%{py_sitedir}/shinken/modules/ndodb_mysql_broker/__init__.py*
%{py_sitedir}/shinken/modules/ndodb_mysql_broker/ndodb_broker.py*
%{py_sitedir}/shinken/modules/ndodb_oracle_broker/__init__.py*
%dir %{py_sitedir}/shinken/modules/ndodb_oracle_broker
%{py_sitedir}/shinken/modules/ndodb_oracle_broker/ndodb_oracle_broker.py*
%{py_sitedir}/shinken/modules/npcdmod_broker.py*
%{py_sitedir}/shinken/modules/nsca_arbiter.py*
%{py_sitedir}/shinken/modules/pickle_retention_file_scheduler.py*
%{py_sitedir}/shinken/modules/redis_retention_scheduler.py*
%dir %{py_sitedir}/shinken/modules/service_perfdata_broker
%{py_sitedir}/shinken/modules/service_perfdata_broker/__init__.py*
%{py_sitedir}/shinken/modules/service_perfdata_broker/service_perfdata_broker.py*
%{py_sitedir}/shinken/modules/simplelog_broker.py*
%dir %{py_sitedir}/shinken/modules/status_dat_broker
%{py_sitedir}/shinken/modules/status_dat_broker/__init__.py*
%{py_sitedir}/shinken/modules/status_dat_broker/objectscache.py*
%{py_sitedir}/shinken/modules/status_dat_broker/status.py*
%{py_sitedir}/shinken/modules/status_dat_broker/status_dat_broker.py*
%{py_sitedir}/shinken/modules/syslog_broker.py*
%{py_sitedir}/shinken/modulesmanager.py*
%{py_sitedir}/shinken/notification.py*
%{py_sitedir}/shinken/notificationway.py*
%{py_sitedir}/shinken/pollerlink.py*
%{py_sitedir}/shinken/property.py*
%{py_sitedir}/shinken/pyro_wrapper.py*
%{py_sitedir}/shinken/reactionnerlink.py*
%{py_sitedir}/shinken/realm.py*
%{py_sitedir}/shinken/resultmodulation.py*
%{py_sitedir}/shinken/satellite.py*
%{py_sitedir}/shinken/satellitelink.py*
%{py_sitedir}/shinken/scheduler.py*
%{py_sitedir}/shinken/schedulerlink.py*
%{py_sitedir}/shinken/schedulingitem.py*
%{py_sitedir}/shinken/service.py*
%{py_sitedir}/shinken/servicedependency.py*
%{py_sitedir}/shinken/serviceescalation.py*
%{py_sitedir}/shinken/servicegroup.py*
%{py_sitedir}/shinken/singleton.py*
%{py_sitedir}/shinken/timeperiod.py*
%{py_sitedir}/shinken/util.py*
%{py_sitedir}/shinken/worker.py*
%dir %{py_sitedir}/skonf
%{py_sitedir}/skonf/__init__.py*
%dir %{py_sitedir}/skonf/arbiters
%{py_sitedir}/skonf/arbiters/__init__.py*
%{py_sitedir}/skonf/arbiters/models.py*
%{py_sitedir}/skonf/arbiters/tests.py*
%{py_sitedir}/skonf/arbiters/views.py*
%dir %{py_sitedir}/skonf/brokers
%{py_sitedir}/skonf/brokers/__init__.py*
%{py_sitedir}/skonf/brokers/models.py*
%{py_sitedir}/skonf/brokers/tests.py*
%{py_sitedir}/skonf/brokers/views.py*
%dir %{py_sitedir}/skonf/common
%{py_sitedir}/skonf/common/__init__.py*
%{py_sitedir}/skonf/common/render.py*
%{py_sitedir}/skonf/manage.py*
%dir %{py_sitedir}/skonf/pollers
%{py_sitedir}/skonf/pollers/__init__.py*
%{py_sitedir}/skonf/pollers/models.py*
%{py_sitedir}/skonf/pollers/tests.py*
%{py_sitedir}/skonf/pollers/views.py*
%dir %{py_sitedir}/skonf/reactionners
%{py_sitedir}/skonf/reactionners/__init__.py*
%{py_sitedir}/skonf/reactionners/models.py*
%{py_sitedir}/skonf/reactionners/tests.py*
%{py_sitedir}/skonf/reactionners/views.py*
%dir %{py_sitedir}/skonf/realms
%{py_sitedir}/skonf/realms/__init__.py*
%{py_sitedir}/skonf/realms/models.py*
%{py_sitedir}/skonf/realms/tests.py*
%{py_sitedir}/skonf/realms/views.py*
%dir %{py_sitedir}/skonf/schedulers
%{py_sitedir}/skonf/schedulers/__init__.py*
%{py_sitedir}/skonf/schedulers/models.py*
%{py_sitedir}/skonf/schedulers/tests.py*
%{py_sitedir}/skonf/schedulers/views.py*
%{py_sitedir}/skonf/settings.py*
%{py_sitedir}/skonf/urls.py*
%dir /var/lib/shinken
/var/lib/shinken/void_for_git

%changelog
* Mon Jan 31 2011 cs@linux-administrator.com
- update to release 0.5.1
* Mon Jun 28 2010 lrupp@novell.com
- initial version 0.1
